@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '1.6'
+Version = '2.0'
 
 import os
 import sys
@@ -37,6 +37,7 @@ ConfigTempTheme     = 'CSSUfeatures_temp_theme'       # name of temp config file
 PathSystemUi        = '/etc/systemui/'                # path to the storage of xml files for the power key menu
 ConfigSystemUi      = 'CSSUfeatures.xml'              # name of the applications' xml file for the power key menu
 updateSettings      = 'updateTransitions'             # name of the script used to pass root commands
+
 #############################################################################################################
 
 def checkFile(Path, File):       
@@ -231,7 +232,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
         self.show()        
         
     def open_website(self):
-        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/Community_SSU/Features'))
+        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/CSSU_Features_Configuration_Editor'))
     def open_bugtracker(self):
         QDesktopServices.openUrl(QUrl('https://bugs.maemo.org'))
 
@@ -261,10 +262,8 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                ##Enable only the valid menu entry 
              if checkFile(PathSystemUi, ConfigSystemUi) == True:
                  self.ui.actionAddPowerKeyEntry.setEnabled(False)
-                 print 'powerKey entry TRUE'
              else:
                  self.ui.actionRemovePowerKeyEntry.setEnabled(False)
-                 print 'powerKey entry FALSE'
              
              ## Check which config file to use.
              checkConfigFile()
@@ -348,6 +347,35 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                  message = 'Reading the configuration settings gave a FATAL ERROR while loading. Not all settings are available.\n\nExiting..'
                  showMessage(message)
                  sys.exit(1)
+                 
+             try:
+                 FMTX = os.popen('gconftool-2 -g /apps/osso/maemo-statusmenu-fmtx/always_visible').read()
+                 AppMenuEditor = os.popen('gconftool-2 -g /apps/osso/hildon-desktop/menu_edit_disabled').read()
+                 DesktopEditor = os.popen('gconftool-2 -g /apps/osso/hildon-desktop/key-actions/disable_edit').read()
+                 RowsStatusMenu = os.popen('gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows').read()
+                 RowsStatusMenuPortrait = os.popen('gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows_portrait').read()
+                 
+                 print FMTX, AppMenuEditor, DesktopEditor, RowsStatusMenu, RowsStatusMenuPortrait
+                 
+                 if FMTX == 'false\n':
+                     self.ui.comboBoxFMTX.setCurrentIndex(0)
+                 else:
+                     self.ui.comboBoxFMTX.setCurrentIndex(1)
+                 if AppMenuEditor == 'false\n':
+                     self.ui.comboBoxAppMenuEditor.setCurrentIndex(0)
+                 else:
+                     self.ui.comboBoxAppMenuEditor.setCurrentIndex(1)
+                 if DesktopEditor == 'false\n':
+                     self.ui.comboBoxDesktopEditor.setCurrentIndex(0)
+                 else:   
+                     self.ui.comboBoxDesktopEditor.setCurrentIndex(1)
+
+                 self.ui.doubleSpinBoxRowsStatusMenu.setValue(int(RowsStatusMenu))
+                 self.ui.doubleSpinBoxRowsStatusMenuPortrait.setValue(int(RowsStatusMenuPortrait))
+             except:
+                 message = 'Reading the configuration settings gave a FATAL ERROR while reading the gconf values. Not all settings are available.\n\nExiting..'
+                 showMessage(message)
+                 sys.exit(1)
 
         def doSetDefault(self):  
              '''Set DEFAULT values in the GUI''' 
@@ -359,7 +387,12 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              self.ui.comboBoxTactile.setCurrentIndex(0)
              self.ui.comboBoxZoomPress.setCurrentIndex(0)
              self.ui.doubleSpinBoxParallax.setValue(float('1.3'))
-             
+             self.ui.comboBoxFMTX.setCurrentIndex(0)
+             self.ui.comboBoxAppMenuEditor.setCurrentIndex(0)
+             self.ui.comboBoxDesktopEditor.setCurrentIndex(0)
+             self.ui.doubleSpinBoxRowsStatusMenu.setValue(int('6'))
+             self.ui.doubleSpinBoxRowsStatusMenuPortrait.setValue(int('8'))
+
              message = 'The DEFAULT configuration options are shown.'
              showQuickMessage(message)
              
@@ -378,6 +411,29 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              ZoomPress       = self.ui.comboBoxZoomPress.currentIndex()
              Parallax        = self.ui.doubleSpinBoxParallax.value()
 
+             if self.ui.comboBoxFMTX.currentIndex() == 0:
+                 FMTX = 'false'
+             else:
+                 FMTX = 'true'    
+             if self.ui.comboBoxAppMenuEditor.currentIndex() == 0:
+                 AppMenuEditor = 'false'
+             else:    
+                 AppMenuEditor =  'true'
+             if self.ui.comboBoxDesktopEditor.currentIndex() == 0:
+                 DesktopEditor = 'false'
+             else:
+                 DesktopEditor =  'true'
+                 
+             RowsStatusMenu = self.ui.doubleSpinBoxRowsStatusMenu.value()
+             RowsStatusMenuPortrait = self.ui.doubleSpinBoxRowsStatusMenuPortrait.value()
+             
+             ##Update of the gconf entries
+             os.system('gconftool-2 -s /apps/osso/maemo-statusmenu-fmtx/always_visible -t bool %s' % FMTX)
+             os.system('gconftool-2 -s /apps/osso/hildon-desktop/menu_edit_disabled -t bool %s' % AppMenuEditor)
+             os.system('gconftool-2 -s /apps/osso/hildon-desktop/key-actions/disable_edit -t bool %s' % DesktopEditor)
+             os.system('gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows -t int %s' % RowsStatusMenu)
+             os.system('gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows_portrait -t int %s' % RowsStatusMenuPortrait)
+
              #Update of the System config file.
              os.rename( PathTemp + ConfigTempSystem, PathTemp + ConfigTempSystem + "~" )
              destination = open( PathTemp + ConfigTempSystem, "w" )
